library(zoo)
library(tseries)

nzdusd <- read.csv("http://ichart.finance.yahoo.com/table.csv?s=nzdusd=x&ignore=.csv", stringsAsFactors=F)
eurusd <- read.csv("http://ichart.finance.yahoo.com/table.csv?s=eurusd=x&ignore=.csv", stringsAsFactors=F)

nzdusd <- zoo(nzdusd[,7], as.Date(nzdusd[,1]))
eurusd <- zoo(eurusd[,7], as.Date(eurusd[,1]))

t.zoo <- merge(nzdusd, eurusd, all=FALSE)
t <- as.data.frame(t.zoo)

cat("Date range is", format(start(t.zoo)), "to", format(end(t.zoo)), "\n")

m <- lm(nzdusd ~ eurusd + 0, data=t)
beta <- coef(m)[1]

cat("Assumed hedge ratio is", beta, "\n")

sprd <- t$nzdusd - beta*t$eurusd
ht <- adf.test(sprd, alternative="stationary", k=0)

cat("ADF p-value is", ht$p.value, "\n")

if (ht$p.value < 0.05) {
    cat("The spread is likely mean-reverting\n")
} else {
    cat("The spread is not mean-reverting.\n")
}
